@@ -36,18 +36,17 @@ ImportImapSettingFinishPageTest::~ImportImapSettingFinishPageTest()
 void ImportImapSettingFinishPageTest::shouldHaveDefaultValue()
 {
     ImportImapSettingFinishPage w;
-    QLabel *label = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto *label = w.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(label);
     QVERIFY(!label->text().isEmpty());
 
-    QTextEdit *mTextEdit = w.findChild<QTextEdit *>(QStringLiteral("textedit"));
+    auto *mTextEdit = w.findChild<QTextEdit *>(QStringLiteral("textedit"));
     QVERIFY(mTextEdit);
     QVERIFY(mTextEdit->isReadOnly());
     QVERIFY(mTextEdit->document()->isEmpty());
 
-    QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
+    auto *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 }
 
 QTEST_MAIN(ImportImapSettingFinishPageTest)
